@@ -212,7 +212,7 @@ class DLL:
                 return a
             else:
                 b.next = sortedMerge(a,b.next)
-                b.next.prev = a
+                b.next.prev = b
                 b.prev = None
                 return b
         
@@ -271,3 +271,6 @@ class DLL:
 
 
 
+
+
+
